import QtQuick 2.7
import QtQuick.Layouts 1.1
import QtQuick.Controls 2.10 as QQC2
import org.kde.kirigami 2.13 as Kirigami
import org.kde.plasma.private.volume 0.1

Kirigami.Page {
    id: flySoundAppletConfigPage
    title: i18n("Settings")
    property var app
    property var config
    property var moduleManager

    Kirigami.FormLayout {
        wideMode: true
        anchors.fill: parent
        Layout.alignment: Qt.AlignTop
        QQC2.CheckBox {
           Kirigami.FormData.label: i18n("Additional:")
           text: i18n("Show peaks")
           checked: config.volumePeaks
           onToggled: { config.volumePeaks = checked; config.save() }
        }
        QQC2.CheckBox {
           text: i18n("Enable shortcuts")
           checked: config.appletShortcuts
           onToggled: { config.appletShortcuts = checked; config.save() }
        }
        QQC2.ComboBox {
            model: [i18n('Always Notify'), i18n('Silent switch'), i18n('Do nothing')]
            onActivated: { config.notify = currentIndex; config.save() }
            Component.onCompleted: { currentIndex = config.notify }
        }
        Kirigami.Separator {
            Kirigami.FormData.isSection: true
        }
        MouseArea {
            id: paMA
            implicitWidth: childrenRect.width
            implicitHeight: childrenRect.height
            hoverEnabled: true
            QQC2.ToolTip.text: i18nd("kcm_pulseaudio", "Requires %1 PulseAudio module", moduleManager.configModuleName)
            QQC2.ToolTip.visible: containsMouse && !paLayout.enabled
            Kirigami.FormData.label: i18n("PulseAudio:")
            Kirigami.FormData.labelAlignment: Qt.AlignTop
            ColumnLayout {
                id: paLayout
                anchors.top: parent.top
                visible: moduleManager.settingsSupported
                enabled: moduleManager.configModuleLoaded
                QQC2.CheckBox {
                    id: virtCheckbox
                    text: i18nd("kcm_pulseaudio", "Add virtual output device for simultaneous output on all local sound cards")
                    checked: moduleManager.combineSinks
                    onToggled: moduleManager.combineSinks = checked;
                }
//                Hide checkbox, because we do not want to allow this functionality to users.
//                It comes from KDE and still exist in that environment.
//                QQC2.CheckBox {
//                    id: switchCheckbox
//                    text: i18nd("kcm_pulseaudio", "Automatically switch all running streams when a new output becomes available")
//                    checked: moduleManager.switchOnConnect
//                    onToggled: moduleManager.switchOnConnect = checked;
//                }
            }
        }
        QQC2.Button {
            text: i18n('Restart PulseAudio')
            onClicked: { app.restartPA() }
            hoverEnabled: true
        }
    }
}
